/*
  Twine - - Twine Shield library for Arduino - Version 0.1
  
  Original release     (0.1) by David Clift-Reaves.

  For more on Twine go to:
  http://supermechanical.com
*/

#ifndef Twine_h
#define Twine_h

#include <inttypes.h>

// library interface description
class Twine {
  public:
    /*
     * Constructor. 
     * This library expects full control of Pin 9 at all times.
     */
    Twine();

    /* 
     * trigger() sends a signal to the Twine.
     * Make sure to configure the Twine to look for the signal and respond to the web.
     * Twine operates on human timescales.  You can only trigger Twine every couple of seconds.
     * This function blocks until it is done triggering the Twine.
     */     
     void trigger();
    
    // Note: The Cloud Sensors aren't currently supported on the Due

    /* 
     * If you want to use the edges of the cloud as capacitive sensors then you must call this function first.
     * Calling is subsequent times re-calibrates the sensors.
     * If you call this function once then this library will expect to use pins 12, 11, 10, and 8. ( This is in addition to 9 which it always needs.)
     */
    void calibrateCloudSensors();

    // This function returns true if the cloud edge closest to the bottom of the cloud shield is touched.
    bool lowerCloudSensorTouched();

    // returns true if the cloud edge above the bottom edge is touched.
    bool upperCloudSensorTouched();
};

#endif

